==> octave-2.9.12.tar.bz2: octave-2.9.12/liboctave/mx-ext.h <==
/*

Copyright (C) 1996, 1997 John W. Eaton

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, write to the Free
Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301, USA.

*/

#if !defined (octave_mx_ext_h)
#define octave_mx_ext_h 1

// Result of a AEP Balance operation.

#include "dbleAEPBAL.h"
#include "CmplxAEPBAL.h"

// Result of a Determinant calculation.

#include "dbleDET.h"
#include "CmplxDET.h"

// Result of a Cholesky Factorization

#include "dbleCHOL.h"
#include "CmplxCHOL.h"

// Result of a Hessenberg Decomposition

#include "dbleHESS.h"
#include "CmplxHESS.h"

// Result of a Schur Decomposition

#include "dbleSCHUR.h"
#include "CmplxSCHUR.h"

// Result of a Singular Value Decomposition.

#include "dbleSVD.h"
#include "CmplxSVD.h"

// Result of an Eigenvalue computation.

#include "EIG.h"

// Result of an LU decomposition.

#include "dbleLU.h"
#include "CmplxLU.h"

// Result of a QR decomposition.

#include "dbleQR.h"
#include "CmplxQR.h"

#include "dbleQRP.h"
#include "CmplxQRP.h"

#endif

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/

==> octave-3.0.5.tar.bz2: octave-3.0.5/liboctave/mx-ext.h <==
/*

Copyright (C) 1994, 1995, 1996, 1997, 1998, 2002, 2005, 2007
              John W. Eaton

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, see
<http://www.gnu.org/licenses/>.

*/

#if !defined (octave_mx_ext_h)
#define octave_mx_ext_h 1

// Result of a AEP Balance operation.

#include "dbleAEPBAL.h"
#include "CmplxAEPBAL.h"

// Result of a Determinant calculation.

#include "dbleDET.h"
#include "CmplxDET.h"

// Result of a Cholesky Factorization

#include "dbleCHOL.h"
#include "CmplxCHOL.h"

// Result of a Hessenberg Decomposition

#include "dbleHESS.h"
#include "CmplxHESS.h"

// Result of a Schur Decomposition

#include "dbleSCHUR.h"
#include "CmplxSCHUR.h"

// Result of a Singular Value Decomposition.

#include "dbleSVD.h"
#include "CmplxSVD.h"

// Result of an Eigenvalue computation.

#include "EIG.h"

// Result of an LU decomposition.

#include "dbleLU.h"
#include "CmplxLU.h"

// Result of a QR decomposition.

#include "dbleQR.h"
#include "CmplxQR.h"

#include "dbleQRP.h"
#include "CmplxQRP.h"

#endif

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/
